@@ -301,6 +301,9 @@ class Station(Table, Base):
     surface_profiler_reading_obj = relationship(
         "SurfaceProfilerReading", back_populates="station_obj", lazy=True, viewonly=True
     )
+    texture_profiler_reading_obj = relationship(
+        "TextureProfilerReading", back_populates="station_obj", lazy=True, viewonly=True
+    )
 
     # Foreign keys:
     __table_args__ = (
@@ -406,6 +409,12 @@ class Interval(Table, Base):
         lazy=True,
         viewonly=True,
     )
+    texture_profiler_session_obj = relationship(
+        "TextureProfilerSession",
+        back_populates="interval_obj",
+        lazy=True,
+        viewonly=True,
+    )
     dynamic_strain_session_obj = relationship(
         "DynamicStrainSession", back_populates="interval_obj", lazy=True, viewonly=True
     )
