@@ -1,7 +1,10 @@
-from collections import defaultdict
 import csv
 import numpy as np
 import pandas as pd
+from collections import defaultdict
+from typing import List
+
+import captif_slp
 
 from captif_db.db.models import (
     DeflectionBeamSession,
@@ -11,6 +14,9 @@ from captif_db.db.models import (
     SurfaceProfilerReading,
     SurfaceProfilerRutDepth,
     SurfaceProfilerTrace,
+    TextureProfilerSession,
+    TextureProfilerReading,
+    TextureProfilerTrace,
     StrainCoilPair,
     DynamicStrainReading,
     DynamicStrainSession,
@@ -26,6 +32,7 @@ from .generic_loaders import DynamicIntervalLoader, StationIntervalLoader
 __all__ = [
     "DeflectionBeamLoader",
     "SurfaceProfilerLoader",
+    "TextureProfilerLoader",
     "DynamicStrainLoader",
 ]
 
@@ -265,6 +272,41 @@ class SurfaceProfilerLoader(StationIntervalLoader):
         )
 
 
+class TextureProfilerLoader(StationIntervalLoader):
+    session_model = TextureProfilerSession
+    reading_model = TextureProfilerReading
+    trace_model = TextureProfilerTrace
+
+    reading_fields = [
+        "mpd",
+        "stdev",
+        "valid_segments",
+        "proportion_valid_segments",
+        "is_valid",
+    ]
+
+    trace_fields = ["distance_mm", "relative_height_mm"]
+
+    def load_raw(self):
+        results = captif_slp.process_files(self.path)
+        results = self._update_field_names(results)
+
+        self.raw_readings = pd.DataFrame(results)
+        self.raw_readings = self.raw_readings.where(pd.notnull(self.raw_readings), None)
+        self.raw_readings["project_id"] = self.project_id  # append project_id column
+
+        self.session_info["session"]["datetime"] = (
+            self.raw_readings["datetime"].min().to_pydatetime()
+        )
+
+    @staticmethod
+    def _update_field_names(results: List[dict]):
+        for ii, _ in enumerate(results):
+            results[ii]["station_no"] = results[ii].pop("file_number")
+            _ = results[ii].pop("distance_m")  # drop distance_m field
+        return results
+
+
 """
 Dynamic strain loader
 
